@@ -332,7 +332,6 @@ class ExecutionFile:
         # parse exec
         self.parse_exec(self.filelines[self.exec_index + 1 :])
 
-
-if __name__ == "__main__":
-    ef = ExecutionFile("example.hermes")
-    ef.parse()
+    def print_lines(self):
+        for line in self.filelines:
+            print(line)
