@@ -31,12 +31,12 @@ def execute_file(args):
     """
     logging.info("Executing from hermes execution file %s", str(args.execution_file))
     execution_file = ExecutionFile(
-        args.execution_file, args.comment if args.comment else []
+        args.execution_file, args.comment if args.comment else [], args.root
     )
-    execution = Execution(execution_file, args.name, args.debug)
     if args.compile_only:
-        execution.print()
+        execution_file.print_lines()
     else:
+        execution = Execution(execution_file, args.name, args.debug)
         execution.run()
 
 
@@ -96,6 +96,7 @@ def detailed_help(args):
     else:
         print("Unknown Command: %s" % args.command)
 
+
 def _git_is_available() -> bool:
     try:
         settings.get_repo_path()
@@ -169,7 +170,7 @@ def main():
     exec_parser.add_argument(
         "--compile_only",
         action="store_true",
-        help="Only compile the hermes file and show what would normally be executed without actually executing anything",
+        help="Only compile the hermes file (i.e. resolve directives) and show what would normally be executed without actually executing anything",
     )
     exec_parser.add_argument(
         "--root",
@@ -179,7 +180,7 @@ def main():
             This argument allows you to override the root path. If git is not available, it is strictly required, otherwise it is optional.
         """,
         required=not git_is_available,
-        default=None
+        default=None,
     )
 
     ## set function to be called for execution command
