@@ -153,6 +153,7 @@ class Experiment:
         # if it already exists throw an error
         experiment_identifier = [
             start_time.strftime(Experiment.TIME_FMT),
+            str(job_idx),
             commit_hash[-5:],
         ]
         experiment_identifier = "_".join(experiment_identifier)
@@ -205,16 +206,16 @@ class Experiment:
             path_to_experiment
         ), "The given path does not store any hermes experiment"
         p = Path(path_to_experiment)
-        script_name, experiment_name, identifier = p.parts[-3:]
+        identifier = str(p.parts[-1])
         info = Experiment.read_info(path_to_experiment)
         commit_hash = info["commit_hash"]
         try:
-            start_time = time.strptime(info["start_time"], Experiment.TIME_FMT)
+            start_time = datetime.strptime(info["start_time"], Experiment.TIME_FMT)
         except:
             try:
                 start_time = float(info["start_time"])
                 logging.info(
-                    "Failed to load experiment start time as time.struct_time, loaded as floating point number instead."
+                    "Failed to load experiment start time as datetime object, loaded as floating point number instead."
                 )
             except:
                 start_time = None
@@ -650,13 +651,13 @@ class Experiment:
         :meta private:
         """
         execution_time = end_time - start_time
-        start_time = time.localtime(start_time)
-        end_time = time.localtime(end_time)
+        start_time = datetime.fromtimestamp(start_time)
+        end_time = datetime.fromtimestamp(end_time)
         self._add_to_info(
-            Experiment.START_TIME_N, time.strftime(Experiment.TIME_FMT, start_time)
+            Experiment.START_TIME_N, start_time.strftime(Experiment.TIME_FMT)
         )
         self._add_to_info(
-            Experiment.END_TIME_N, time.strftime(Experiment.TIME_FMT, end_time)
+            Experiment.END_TIME_N, end_time.strftime(Experiment.TIME_FMT)
         )
         self._add_to_info(Experiment.EXECUTION_TIME_N, str(execution_time))
 
